Installation
==================
To get started using DaCy simply install it using pip by running the following line in your terminal:

.. code-block::

   pip install dacy

Installing from source
^^^^^^^^^^^^^^^^^^^^^^^^^

You can also install DaCy directly from source using:

.. code-block::

   git clone https://github.com/centre-for-humanities-computing/DaCy.git
   cd DaCy
   pip install .

or

.. code-block::

   pip install git+https://github.com/centre-for-humanities-computing/DaCy
